@@ -11,7 +11,9 @@ import publication
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-medialive", "1.47.0", __name__[0:-6], "aws-medialive@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-medialive", "1.61.0", __name__[0:-6], "aws-medialive@1.61.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
